pub struct SupportedObjectType {
pub object_type: ObjectType,
pub createable: bool,
pub deletable: bool,
}Expand description
A BACnet object type supported by the device.
Fields
object_type: ObjectTypeThe object type.
createable: boolWhether objects of this type can be dynamically created.
deletable: boolWhether objects of this type can be dynamically deleted.