Module server

Module server 

BACnet server/responder implementation. BACnet server/responder implementation.

BacnetServer binds a [DataLink] transport and dispatches incoming service requests to a user-supplied ServiceHandler. ObjectStore is a convenient thread-safe property store that implements ServiceHandler out of the box.

Structs

BacnetServer
A server that binds a DataLink and dispatches incoming service requests.
ObjectStore
Thread-safe property store backed by Mutex<HashMap<ObjectId, HashMap<PropertyId, ClientDataValue>>>.
ObjectStoreHandler
A ServiceHandler that delegates directly to an Arc<ObjectStore>.

Enums

BacnetServiceError
Errors that a ServiceHandler may return.

Traits

ServiceHandler
Handler trait that the server calls for each incoming service request.