pub struct SimulatedDevice<D: DataLink> {
pub device_id: ObjectId,
/* private fields */
}Expand description
A simulated BACnet device.
Fields
device_id: ObjectIdImplementations
Sourceimpl<D: DataLink> SimulatedDevice<D>
impl<D: DataLink> SimulatedDevice<D>
Sourcepub fn new(instance: u32, datalink: D) -> Self
pub fn new(instance: u32, datalink: D) -> Self
Create a new simulated device with the given instance number.
Sourcepub async fn add_object(
&self,
id: ObjectId,
properties: HashMap<PropertyId, ClientDataValue>,
)
pub async fn add_object( &self, id: ObjectId, properties: HashMap<PropertyId, ClientDataValue>, )
Add an object with its properties to the simulated device.
Sourcepub async fn run(&self) -> Result<(), ClientError>
pub async fn run(&self) -> Result<(), ClientError>
Run the device loop, responding to incoming requests until stopped.